"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ActionsSignatures = void 0;
const assert_1 = __importDefault(require("assert"));
const api_tools_core_1 = require("@fresha/api-tools-core");
const code_morph_ts_1 = require("@fresha/code-morph-ts");
const openapi_codegen_utils_1 = require("@fresha/openapi-codegen-utils");
const ActionSignature_1 = require("./ActionSignature");
const operations_1 = require("./operations");
/**
 * Generates the type alias, containing signatures of all API actions.
 * For each action, delegates the task of generating its signature to ActionSignature part.
 *
 * @see ActionSignature
 */
class ActionsSignatures {
    constructor(context, sourceFile) {
        this.context = context;
        this.sourceFile = sourceFile;
        this.name = (0, api_tools_core_1.titleCase)(`${this.context.apiName.replace('-api', '')}Actions`);
        this.actions = new Map();
    }
    collectData() {
        for (const operation of (0, openapi_codegen_utils_1.getOperations)(this.context.openapi)) {
            const entryKey = (0, openapi_codegen_utils_1.getOperationEntryKeyOrThrow)(operation);
            const { template } = (0, operations_1.findOperationTemplate)(operation.httpMethod, operation.parent.pathUrl, entryKey, (0, openapi_codegen_utils_1.getOperationId)(operation));
            const actionName = (0, openapi_codegen_utils_1.getOperationId)(operation) ?? template.actionName(entryKey);
            (0, assert_1.default)(!this.actions.has(actionName));
            this.actions.set(actionName, new ActionSignature_1.ActionSignature(this.context, actionName, operation, template));
        }
    }
    generateCode() {
        this.context.logger.info(`Generating actions shape type, ${this.name}`);
        const returnTypeObj = (0, code_morph_ts_1.addTypeLiteralAlias)(this.sourceFile, this.name, true);
        for (const action of this.actions.values()) {
            action.generateCode(returnTypeObj);
        }
        (0, code_morph_ts_1.addConstant)(this.sourceFile, (0, api_tools_core_1.camelCase)(this.context.apiName), `boundActions(store, configuredApi) as ${this.name}`, true);
    }
}
exports.ActionsSignatures = ActionsSignatures;
//# sourceMappingURL=ActionsSignatures.js.map