"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Generator = void 0;
const path_1 = __importDefault(require("path"));
const openapi_codegen_utils_1 = require("@fresha/openapi-codegen-utils");
const ActionsSignatures_1 = require("./ActionsSignatures");
const APIConfig_1 = require("./APIConfig");
const TestFile_1 = require("./TestFile");
/**
 * Root generator. It doesn't generate the code itself, instead delegating work to its parts.
 */
class Generator extends openapi_codegen_utils_1.Generator {
    constructor(context) {
        super(context);
        this.sourceFile = this.context.project.createSourceFile(path_1.default.join(this.context.outputPath, 'src', 'index.ts'), '', { overwrite: true });
        this.apiConfig = new APIConfig_1.APIConfig(this.context, this.sourceFile);
        this.actionsSignatures = new ActionsSignatures_1.ActionsSignatures(this.context, this.sourceFile);
        this.testFile = new TestFile_1.TestFile(this.context);
    }
    collectData() {
        this.apiConfig.collectData();
        this.actionsSignatures.collectData();
        this.testFile.collectData();
    }
    generateCode() {
        this.apiConfig.generateCode();
        this.actionsSignatures.generateCode();
        this.testFile.generateCode();
        if (!this.context.dryRun) {
            this.context.project.saveSync();
        }
    }
}
exports.Generator = Generator;
//# sourceMappingURL=Generator.js.map