"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.findOperationTemplate = exports.OPERATION_TEMPLATES_MAP = void 0;
const assert_1 = __importDefault(require("assert"));
const openapi_codegen_utils_1 = require("@fresha/openapi-codegen-utils");
const OPERATION_TEMPLATES_LIST = [
    {
        name: 'list',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`read_${entryKey}_list`),
        httpMethod: 'get',
        hasRequestBody: false,
        makeUrl: (urlBase) => urlBase,
    },
    {
        name: 'read',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`read_${entryKey}`),
        httpMethod: 'get',
        hasRequestBody: false,
        makeUrl: (urlBase) => (urlBase.includes(':id') ? urlBase : `${urlBase}/:id`),
    },
    {
        name: 'single-read',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`read_${entryKey}`),
        httpMethod: 'get',
        hasRequestBody: false,
        makeUrl: (urlBase) => urlBase,
    },
    {
        name: 'create',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`create_${entryKey}`),
        httpMethod: 'post',
        hasRequestBody: true,
        makeUrl: (urlBase) => urlBase,
    },
    {
        name: 'update',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`update_${entryKey}`),
        httpMethod: 'put',
        hasRequestBody: true,
        makeUrl: (urlBase) => (urlBase.includes(':id') ? urlBase : `${urlBase}/:id`),
    },
    {
        name: 'single-update',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`update_${entryKey}`),
        hasRequestBody: true,
        httpMethod: 'put',
        makeUrl: (urlBase) => urlBase,
    },
    {
        name: 'patch',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`patch_${entryKey}`),
        httpMethod: 'patch',
        hasRequestBody: true,
        makeUrl: (urlBase) => (urlBase.includes(':id') ? urlBase : `${urlBase}/:id`),
    },
    {
        name: 'single-patch',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`patch_${entryKey}`),
        httpMethod: 'patch',
        hasRequestBody: true,
        makeUrl: (urlBase) => urlBase,
    },
    {
        name: 'delete',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`delete_${entryKey}`),
        httpMethod: 'delete',
        hasRequestBody: false,
        makeUrl: (urlBase) => (urlBase.includes(':id') ? urlBase : `${urlBase}/:id`),
    },
    {
        name: 'single-delete',
        actionName: (entryKey) => (0, openapi_codegen_utils_1.camelCase)(`delete_${entryKey}`),
        httpMethod: 'delete',
        hasRequestBody: false,
        makeUrl: (urlBase) => urlBase,
    },
];
exports.OPERATION_TEMPLATES_MAP = Object.fromEntries(OPERATION_TEMPLATES_LIST.map(template => [template.name, template]));
const findOperationTemplate = (httpMethod, itemPath, entryKey, operationId) => {
    let templateName = null;
    if (httpMethod === 'get') {
        if (itemPath.includes('{id}')) {
            templateName = 'read';
        }
        else {
            const singleReadTemplate = exports.OPERATION_TEMPLATES_MAP['single-read'];
            if (singleReadTemplate.actionName(entryKey) === operationId) {
                templateName = 'single-read';
            }
            else {
                templateName = 'list';
            }
        }
    }
    else if (httpMethod === 'post') {
        templateName = 'create';
    }
    else if (httpMethod === 'put') {
        templateName = itemPath.includes('{id}') ? 'update' : 'single-update';
    }
    else if (httpMethod === 'patch') {
        templateName = itemPath.includes('{id}') ? 'patch' : 'single-patch';
    }
    else if (httpMethod === 'delete') {
        templateName = itemPath.includes('{id}') ? 'delete' : 'single-delete';
    }
    (0, assert_1.default)(templateName, `Unsupported http method ${httpMethod}`);
    const template = exports.OPERATION_TEMPLATES_MAP[templateName];
    (0, assert_1.default)(template, `Unsupported operation template name ${templateName}`);
    return { template, name: templateName };
};
exports.findOperationTemplate = findOperationTemplate;
//# sourceMappingURL=operations.js.map